==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DataGridSortIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SortIndicatorRenderCompletedEventArgsDescriptionMetadata } from "./SortIndicatorRenderCompletedEventArgsDescriptionMetadata";
import { DataGridSortIndicatorDescription } from "./DataGridSortIndicatorDescription";
/**
 * @hidden
 */
var DataGridSortIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataGridSortIndicatorDescriptionMetadata, _super);
    function DataGridSortIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataGridSortIndicatorDescriptionMetadata.b = function (a) {
        if (DataGridSortIndicatorDescriptionMetadata.a == null) {
            DataGridSortIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataGridSortIndicatorDescriptionMetadata.c(DataGridSortIndicatorDescriptionMetadata.a);
        }
        if (a.g(DataGridSortIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.s(DataGridSortIndicatorDescriptionMetadata.a);
        SortIndicatorRenderCompletedEventArgsDescriptionMetadata.d(a);
    };
    DataGridSortIndicatorDescriptionMetadata.c = function (a) {
        a.item("SortDirection", "ExportedType:string:ColumnSortDirection");
        a.item("SortDirection@names", "None;Ascending;Descending");
        a.item("IconColor", "Brush");
        a.item("IsAnimationEnabled", "Boolean");
        a.item("PixelScalingRatio", "Number:double");
        a.item("ActualPixelScalingRatio", "Number:double");
        a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
        a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
        a.item("RenderCompletedRef", "EventRef::renderCompleted");
    };
    DataGridSortIndicatorDescriptionMetadata.d = function (a) {
        DataGridSortIndicatorDescriptionMetadata.b(a);
        a.u("DataGridSortIndicator", function () { return new DataGridSortIndicatorDescription(); });
        a.t("DataGridSortIndicator", DataGridSortIndicatorDescriptionMetadata.a);
    };
    DataGridSortIndicatorDescriptionMetadata.$t = markType(DataGridSortIndicatorDescriptionMetadata, 'DataGridSortIndicatorDescriptionMetadata');
    DataGridSortIndicatorDescriptionMetadata.a = null;
    return DataGridSortIndicatorDescriptionMetadata;
}(Base));
export { DataGridSortIndicatorDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DataGridSortIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SortIndicatorRenderCompletedEventArgsDescriptionMetadata } from "./SortIndicatorRenderCompletedEventArgsDescriptionMetadata";
import { DataGridSortIndicatorDescription } from "./DataGridSortIndicatorDescription";
/**
 * @hidden
 */
var DataGridSortIndicatorDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DataGridSortIndicatorDescriptionMetadata, _super);
    function DataGridSortIndicatorDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DataGridSortIndicatorDescriptionMetadata.b = function (a) {
        if (DataGridSortIndicatorDescriptionMetadata.a == null) {
            DataGridSortIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DataGridSortIndicatorDescriptionMetadata.c(DataGridSortIndicatorDescriptionMetadata.a);
        }
        if (a.j(DataGridSortIndicatorDescriptionMetadata.a)) {
            return;
        }
        a.y(DataGridSortIndicatorDescriptionMetadata.a);
        SortIndicatorRenderCompletedEventArgsDescriptionMetadata.d(a);
    };
    DataGridSortIndicatorDescriptionMetadata.c = function (a) {
        a.item("SortDirection", "ExportedType:string:ColumnSortDirection");
        a.item("SortDirection@names", "None;Ascending;Descending");
        a.item("IconColor", "Brush");
        a.item("IsAnimationEnabled", "Boolean");
        a.item("PixelScalingRatio", "Number:double");
        a.item("ActualPixelScalingRatio", "Number:double");
        a.item("SortIndicatorStyle", "ExportedType:string:SortIndicatorStyle");
        a.item("SortIndicatorStyle@names", "Default;FadingUpDownArrows;FadingSimpleUpDownArrows;Unset");
        a.item("RenderCompletedRef", "EventRef::renderCompleted");
    };
    DataGridSortIndicatorDescriptionMetadata.d = function (a) {
        DataGridSortIndicatorDescriptionMetadata.b(a);
        a.aa("DataGridSortIndicator", function () { return new DataGridSortIndicatorDescription(); });
        a.z("DataGridSortIndicator", DataGridSortIndicatorDescriptionMetadata.a);
    };
    DataGridSortIndicatorDescriptionMetadata.$t = markType(DataGridSortIndicatorDescriptionMetadata, 'DataGridSortIndicatorDescriptionMetadata');
    DataGridSortIndicatorDescriptionMetadata.a = null;
    return DataGridSortIndicatorDescriptionMetadata;
}(Base));
export { DataGridSortIndicatorDescriptionMetadata };
